function [EEG] = baselineCorForGaps(EEG,npreTMS,npostTMS,nbeforeTMS,nafterTMS,imin)
%  Executes baseline correction to the EEG data, using segments of a
%  specific duration from pre- and post-gap data the following way:
%  a) Average the post-TMS segments to derive a "prototype".
%  b) Compute a baseline (from averaging) from the pre-TMS segments.
%  c) For each epoch, subtract the prototype from the post-TMS and bring
%  the residual to the pre-TMS baseline.
%  INPUT
%  -EEG            : EEG struct
%  -npreTMS        : duration of the pre-TMS segment
%  -npostTMS       : duration of the post-TMS segment
%  -nbeforeTMS     : index corresponding to the beginning of the gap
%  -nafterTMS      : index corresponding to the end of the gap
%  -imin           : index corresponding to the TMS event
%  OUTPUT
%  -EEG            : baseline corrected EEG struct

outlierprc = 2.5; %Percentage for trimmed mean

%initializing cells for the pre- and post-TMS segments
preTMSbaseData = {};
postTMSbaseData = {};
for a = 1: size(EEG.data,1) %for every channel
    preTMSbaseData_epoch = [];
    postTMSbaseData_epoch = [];
    for b= 1 : size(EEG.data,3) %for every epoch
        %get pre- and post-TMS segmets' data
        preTMSbaseData_epoch = [preTMSbaseData_epoch;EEG.data(a,imin-npreTMS:nbeforeTMS,b)];
        postTMSbaseData_epoch = [postTMSbaseData_epoch;EEG.data(a,nafterTMS:imin+npostTMS,b)];
    end
    add{1,1} = preTMSbaseData_epoch;
    add2{1,1} = postTMSbaseData_epoch;
    preTMSbaseData = [preTMSbaseData;add];
    postTMSbaseData = [postTMSbaseData;add2]; 
end

meanpreTMSV = NaN*ones(size(EEG.data,1),1);
meanpostTMSM = NaN*ones(size(EEG.data,1),size(postTMSbaseData{1},2));
for a = 1 : size(EEG.data,1)
    %compute baseline and prototype
    meanpreTMSV(a) = trimmean(trimmean(preTMSbaseData{a},outlierprc),outlierprc);
    meanpostTMSM(a,:) = trimmean(postTMSbaseData{a},outlierprc);
end

for b = 1 : size(EEG.data,3)
    xnewM = EEG.data(:,:,b)';
    for a = 1 : size(EEG.data,1)
        %execute baseline correction by removing the protorype from every
        %channel of every epoch and adding the baseline from the pre-TMS
        %segment
        xnewM(nafterTMS:imin+npostTMS,a)=EEG.data(a,nafterTMS:imin+npostTMS,b)'...
            -meanpostTMSM(a,1:imin+npostTMS-nafterTMS+1)'+meanpreTMSV(a);
    end
    EEG.data(:,:,b) = xnewM';
end
end

